aboutsummaryrefslogtreecommitdiffstats
path: root/tools/pidl/lib
diff options
context:
space:
mode:
Diffstat (limited to 'tools/pidl/lib')
-rw-r--r--tools/pidl/lib/Parse/Pidl/Samba3/ServerNDR.pm4
1 files changed, 2 insertions, 2 deletions
diff --git a/tools/pidl/lib/Parse/Pidl/Samba3/ServerNDR.pm b/tools/pidl/lib/Parse/Pidl/Samba3/ServerNDR.pm
index c87d17a5a7..4857585bba 100644
--- a/tools/pidl/lib/Parse/Pidl/Samba3/ServerNDR.pm
+++ b/tools/pidl/lib/Parse/Pidl/Samba3/ServerNDR.pm
@@ -62,11 +62,11 @@ sub AllocOutVar($$$$$$$)
$l = $nl if ($nl->{TYPE} eq "ARRAY");
} elsif
# we don't support multi-dimentional arrays yet
($l->{TYPE} eq "ARRAY") {
my $nl = GetNextLevel($e, $l);
if ($nl->{TYPE} eq "ARRAY") {
- fatal($e->{ORIGINAL},"multi-dimentional [out] arrays are not supported!");
+ fatal($e->{ORIGINAL},"multi-dimensional [out] arrays are not supported!");
}
} else {
# neither pointer nor array, no need to alloc something.
@@ -62,11 +62,11 @@ sub AllocOutVar($$$$$$$)
$l = $nl if ($nl->{TYPE} eq "ARRAY");
} elsif
- # we don't support multi-dimentional arrays yet
+ # we don't support multi-dimensional arrays yet
($l->{TYPE} eq "ARRAY") {
my $nl = GetNextLevel($e, $l);